@@ -3,7 +3,7 @@ use warnings;
 
 package Gentoo::Overlay;
 BEGIN {
-  $Gentoo::Overlay::VERSION = '0.01000020';
+  $Gentoo::Overlay::VERSION = '0.02004319';
 }
 
 # ABSTRACT: Tools for working with Gentoo Overlays
@@ -22,15 +22,15 @@ use Gentoo::Overlay::Types qw( :all );
 
 
 
-has 'path' => ( isa => Dir, ro, required, coerce );
+has 'path' => isa => Dir, ro, required, coerce;
 
 
-has 'name' => ( isa => Str, ro, lazy_build );
+has 'name' => isa => Gentoo__Overlay_RepositoryName, ro, lazy_build;
 
 
 sub _build_name {
   my ($self) = shift;
-  my $f = $self->default_path('repo_name');
+  my $f = $self->default_path( repo_name => );
   if ( ( !-e $f ) or ( !-f $f ) ) {
     Carp::croak( sprintf qq{No repo_name file for overlay at: %s\n Expects:%s}, $self->path->stringify, $f->stringify );
   }
@@ -38,12 +38,12 @@ sub _build_name {
 }
 
 
-has '_profile_dir' => ( isa => Dir, ro, lazy_build );
+has _profile_dir => isa => Dir, ro, lazy_build;
 
 
 sub _build__profile_dir {
   my ($self) = shift;
-  my $pd = $self->default_path('profiles');
+  my $pd = $self->default_path( profiles => );
   if ( ( !-e $pd ) or ( !-d $pd ) ) {
     Carp::croak( sprintf qq{No profile directory for overlay at: %s\n  Expects:%s}, $self->path->stringify, $pd->stringify, );
   }
@@ -55,16 +55,15 @@ sub _build__profile_dir {
 
 
 
-has(
-  '_categories' => ( isa => HashRef [Gentoo__Overlay_Category], ro, lazy_build ),
-  traits        => [qw( Hash )],
-  handles       => {
-    '_has_category'  => 'exists',
-    'category_names' => 'keys',
-    'categories'     => 'elements',
-    'get_category'   => 'get',
-  }
-);
+has _categories => isa => HashRef [Gentoo__Overlay_Category],
+  ro, lazy_build,
+  traits  => [qw( Hash )],
+  handles => {
+  _has_category  => exists   =>,
+  category_names => keys     =>,
+  categories     => elements =>,
+  get_category   => get      =>,
+  };
 
 
 sub _build__categories {
@@ -79,17 +78,17 @@ sub _build__categories {
 }
 
 
-class_has( '_default_paths' => ( isa => HashRef [CodeRef], ro, lazy_build ), );
-
-
-sub _build__default_paths {
+class_has _default_paths => isa => HashRef [CodeRef],
+  ro, lazy, default => sub {
   return {
     'profiles'  => sub { shift->path->subdir('profiles') },
     'repo_name' => sub { shift->_profile_dir->file('repo_name') },
     'catfile'   => sub { shift->_profile_dir->file('categories') },
     'category'  => sub { shift->path->subdir(shift) },
+    'package'   => sub { shift->default_path( 'category', shift )->subdir(shift) },
+  };
+
   };
-}
 
 
 sub default_path {
@@ -129,12 +128,13 @@ sub _build___categories_scan {
   ## no critic ( ProhibitTies )
   tie my %dir, 'IO::Dir', $self->path->absolute->stringify;
   for my $cat ( sort keys %dir ) {
+    next if Gentoo::Overlay::Category->is_blacklisted($cat);
+
     my $category = Gentoo::Overlay::Category->new(
       overlay => $self,
       name    => $cat,
     );
     next unless $category->exists();
-    next if $category->is_blacklisted();
     $out{$cat} = $category;
   }
   return \%out;
@@ -155,7 +155,7 @@ Gentoo::Overlay - Tools for working with Gentoo Overlays
 
 =head1 VERSION
 
-version 0.01000020
+version 0.02004319
 
 =head1 SYNOPSIS
 
@@ -217,9 +217,9 @@ L<MooseX::Types::Path::Class/Dir>
 
 Repository name.
 
-    isa => Str, ro, lazy_build
+    isa => Gentoo__Overlay_RepositoryName, ro, lazy_build
 
-L<< C<MooseX::Types::Moose>|MooseX::Types::Moose >>
+L<< C<RepositoryName>|Gentoo::Overlay::Types/Gentoo__Overlay_RepositoryName >>
 
 L</_build_name>
 
@@ -347,23 +347,13 @@ that are files and/or blacklisted.
 
     $overlay->_build___categories_scan
 
-=head1 PRIVATE CLASS METHODS
-
-=head2 _build__default_paths
-
-Generator of the class-wide default path list.
-
-    ::Overlay->_build__default_paths
-
-L</_default_paths>
-
 =head1 AUTHOR
 
 Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2011 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
